bayespy.nodes.Gamma
===================

.. currentmodule:: bayespy.nodes

.. autoclass:: Gamma

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Gamma.__init__
      ~Gamma.add_plate_axis
      ~Gamma.as_diagonal_wishart
      ~Gamma.broadcasting_multiplier
      ~Gamma.delete
      ~Gamma.get_gradient
      ~Gamma.get_mask
      ~Gamma.get_moments
      ~Gamma.get_parameters
      ~Gamma.get_riemannian_gradient
      ~Gamma.get_shape
      ~Gamma.has_plotter
      ~Gamma.initialize_from_parameters
      ~Gamma.initialize_from_prior
      ~Gamma.initialize_from_random
      ~Gamma.initialize_from_value
      ~Gamma.load
      ~Gamma.logpdf
      ~Gamma.lower_bound_contribution
      ~Gamma.lowerbound
      ~Gamma.move_plates
      ~Gamma.observe
      ~Gamma.pdf
      ~Gamma.plot
      ~Gamma.random
      ~Gamma.save
      ~Gamma.set_parameters
      ~Gamma.set_plotter
      ~Gamma.show
      ~Gamma.unobserve
      ~Gamma.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Gamma.dims
      ~Gamma.plates
      ~Gamma.plates_multiplier
   
   